@@ -23,7 +23,7 @@ import re, os
 
 
 # The current version of rdiff-backup
-version = "0.11.4"
+version = "0.11.5"
 
 # If this is set, use this value in seconds as the current time
 # instead of reading it from the clock.
@@ -53,6 +53,9 @@ process_gid = os.getgid()
 # If true, when copying attributes, also change target's uid/gid
 change_ownership = None
 
+# If true, when copying attributes, also change target's permission.
+change_permissions = 1
+
 # If true, change the permissions of unwriteable mirror files
 # (such as directories) so that they can be written, and then
 # change them back.  This defaults to 1 just in case the process
@@ -176,6 +179,10 @@ restrict_path = None
 # the man page under --no-compare-inode for more information.
 compare_inode = 1
 
+# If set, directories can be fsync'd just like normal files, to
+# guarantee that any changes have been committed to disk.
+fsync_directories = 1
+
 
 def get(name):
 	"""Return the value of something in this module"""
