@@ -51,7 +51,7 @@ def parse_cmdlineoptions(arglist):
 		  "exclude-regexp=", "exclude-special-files", "force",
 		  "include=", "include-filelist=", "include-filelist-stdin",
 		  "include-globbing-filelist=", "include-regexp=",
-		  "list-changed-since=", "list-increments",
+		  "list-at-time=", "list-changed-since=", "list-increments",
 		  "no-compare-inode", "no-compression",
 		  "no-compression-regexp=", "no-file-statistics",
 		  "no-hard-links", "null-separator", "parsable-output",
@@ -60,7 +60,7 @@ def parse_cmdlineoptions(arglist):
 		  "restrict=", "restrict-read-only=", "restrict-update-only=",
 		  "server", "ssh-no-compression", "terminal-verbosity=",
 		  "test-server", "verbosity=", "version", "windows-mode",
-		  "windows-time-format"])
+		  "windows-restore"])
 	except getopt.error, e:
 		commandline_error("Bad commandline options: %s" % str(e))
 
@@ -101,6 +101,8 @@ def parse_cmdlineoptions(arglist):
 			select_opts.append((opt, arg))
 			select_files.append(sel_fl(arg))
 		elif opt == "--include-regexp": select_opts.append((opt, arg))
+		elif opt == "--list-at-time":
+			restore_timestr, action = arg, "list-at-time"
 		elif opt == "--list-changed-since":
 			restore_timestr, action = arg, "list-changed-since"
 		elif opt == "-l" or opt == "--list-increments":
@@ -143,9 +145,15 @@ def parse_cmdlineoptions(arglist):
 			sys.exit(0)
 		elif opt == "-v" or opt == "--verbosity": Log.setverbosity(arg)
 		elif opt == "--windows-mode":
-			Globals.set('chars_to_quote', "A-Z:")
+			Globals.set('chars_to_quote', "^a-z0-9._ -")
 			Globals.set('quoting_enabled', 1)
 			Globals.set('preserve_hardlinks', 0)
+			Globals.set('change_ownership', 0)
+			Globals.set('change_permissions', 0)
+			Globals.set('fsync_directories', 0)
+		elif opt == '--windows-restore':
+			Globals.set('chars_to_quote', "^a-z0-9._ -")
+			Globals.set('quoting_enabled', 1)
 		else: Log.FatalError("Unknown option %s" % opt)
 
 def isincfilename(path):
@@ -178,6 +186,7 @@ def set_action():
 		commandline_error("Two arguments are required (source, destination).")
 	if l == 2 and (action == "list-increments" or
 				   action == "remove-older-than" or
+				   action == "list-at-time" or
 				   action == "list-changed-since" or
 				   action == "check-destination-dir"):
 		commandline_error("Only use one argument, "
@@ -211,6 +220,7 @@ def take_action(rps):
 	elif action == "restore": Restore(*rps)
 	elif action == "restore-as-of": RestoreAsOf(rps[0], rps[1])
 	elif action == "test-server": SetConnections.TestConnections()
+	elif action == "list-at-time": ListAtTime(rps[0])
 	elif action == "list-changed-since": ListChangedSince(rps[0])
 	elif action == "list-increments": ListIncrements(rps[0])
 	elif action == "remove-older-than": RemoveOlderThan(rps[0])
@@ -281,7 +291,8 @@ def backup_init_dirs(rpin, rpout):
 
 	if rpout.lstat():
 		if rpout.isdir() and not rpout.listdir(): # rpout is empty dir
-			rpout.chmod(0700) # just make sure permissions aren't too lax
+			if Globals.change_permissions:
+				rpout.chmod(0700) # just make sure permissions aren't too lax
 		elif not datadir.lstat() and not force: Log.FatalError(
 """Destination directory
 
@@ -355,7 +366,7 @@ def backup_remove_curmirror_local():
 	else: older_inc = curmir_incs[1]
 
 	C.sync() # Make sure everything is written before curmirror is removed
-	older_inc.sync_delete()
+	older_inc.delete()
 
 
 def Restore(src_rp, dest_rp = None):
@@ -527,7 +538,7 @@ def RemoveOlderThan(rootrp):
 	times_in_secs = filter(lambda t: t < time, times_in_secs)
 	if not times_in_secs:
 		Log.FatalError("No increments older than %s found, exiting."
-					   % (timep,), 1)
+					   % (timep,), 1, errlevel = 0)
 
 	times_in_secs.sort()
 	inc_pretty_time = "\n".join(map(Time.timetopretty, times_in_secs))
@@ -562,6 +573,17 @@ def ListChangedSince(rp):
 	restore.ListChangedSince(mirror_rp, inc_rp, rest_time)
 
 
+def ListAtTime(rp):
+	"""List files in archive under rp that are present at restoretime"""
+	try: rest_time = Time.genstrtotime(restore_timestr)
+	except Time.TimeException, exc: Log.FatalError(str(exc))
+	mirror_root, index = restore_get_root(rp)
+	restore_check_backup_dir(mirror_root)
+	mirror_rp = mirror_root.new_index(index)
+	inc_rp = mirror_rp.append_path("increments", index)
+	restore.ListAtTime(mirror_rp, inc_rp, rest_time)
+	
+
 def CheckDest(dest_rp):
 	"""Check the destination directory, """
 	if Globals.rbdir is None:
