@@ -94,8 +94,8 @@ def set_security_level(action, cmdpairs):
 			sec_level = "all"
 			rdir = getpath(cp2)
 	elif (action == "test-server" or action == "list-increments" or
-		  action == "list-changed-since" or action ==
-		  "calculate-average" or action == "remove-older-than"):
+		  action == "list-at-time" or action == "list-changed-since"
+		  or action == "calculate-average" or action == "remove-older-than"):
 		sec_level = "minimal"
 		rdir = tempfile.gettempdir()
 	else: assert 0, "Unknown action %s" % action
@@ -121,6 +121,7 @@ def set_allowed_requests(sec_level):
 	elif sec_level == "read-only" or sec_level == "update-only":
 		allowed_requests.extend(
 			["C.make_file_dict",
+			 "log.Log.log_to_file",
 			 "os.getuid",
 			 "os.listdir",
 			 "Time.setcurtime_local",
