@@ -283,8 +283,12 @@ class CacheCollatedPostProcess:
 		"""Remove one element from cache, possibly adding it to metadata"""
 		first_index = self.cache_indicies[0]
 		del self.cache_indicies[0]
-		old_source_rorp, old_dest_rorp, changed_flag, success_flag, inc = \
-						 self.cache_dict[first_index]
+		try: (old_source_rorp, old_dest_rorp, changed_flag,
+			  success_flag, inc) = self.cache_dict[first_index]
+		except KeyError: # probably caused by error in file system (dup)
+			log.Log("Warning index %s missing from CCPP cache" %
+					(first_index,),2)
+			return
 		del self.cache_dict[first_index]
 		self.post_process(old_source_rorp, old_dest_rorp,
 						  changed_flag, success_flag, inc)
@@ -408,7 +412,10 @@ class PatchITRB(rorpiter.ITRBranch):
 		if diff_rorp.isflaglinked():
 			Hardlink.link_rp(diff_rorp, new, self.basis_root_rp)
 		elif diff_rorp.get_attached_filetype() == 'snapshot':
-			if diff_rorp.isspecial(): self.write_special(diff_rorp, new)
+			if diff_rorp.isspecial():
+				self.write_special(diff_rorp, new)
+				rpath.copy_attribs(diff_rorp, new)
+				return 1
 			elif robust.check_common_error(self.error_handler, rpath.copy,
 										   (diff_rorp, new)) == 0: return 0
 		else:
@@ -465,7 +472,7 @@ class PatchITRB(rorpiter.ITRBranch):
 									self.dir_replacement)
 			success = 0
 		else: success = 1
-		if base_rp.isdir(): base_rp.chmod(0700)
+		if base_rp.isdir() and Globals.change_permissions: base_rp.chmod(0700)
 		return success
 
 	def prepare_dir(self, diff_rorp, base_rp):
@@ -478,7 +485,7 @@ class PatchITRB(rorpiter.ITRBranch):
 		else: # maybe no change, so query CCPP before tagging success
 			if self.CCPP.in_cache(diff_rorp.index):
 				self.CCPP.flag_success(diff_rorp.index)
-		base_rp.chmod(0700)
+		if Globals.change_permissions: base_rp.chmod(0700)
 
 	def end_process(self):
 		"""Finish processing directory"""
