@@ -82,6 +82,16 @@ def ListChangedSince(mirror_rp, inc_rp, restore_to_time):
 		print "%-7s %s" % (change, path_desc)
 
 
+def ListAtTime(mirror_rp, inc_rp, time):
+	"""List the files in archive at the given time"""
+	MirrorS = mirror_rp.conn.restore.MirrorStruct
+	MirrorS.set_mirror_and_rest_times(time)
+	MirrorS.initialize_rf_cache(mirror_rp, inc_rp)
+
+	old_iter = MirrorS.get_mirror_rorp_iter(_rest_time, 1)
+	for rorp in old_iter: print rorp.get_indexpath()
+	
+
 class MirrorStruct:
 	"""Hold functions to be run on the mirror side"""
 	def set_mirror_and_rest_times(cls, restore_to_time):
@@ -371,7 +381,8 @@ class RestoreFile:
 
 	def get_restore_fp(self):
 		"""Return file object of restored data"""
-		assert self.relevant_incs[-1].isreg()
+		assert self.relevant_incs[-1].isreg(), \
+			   (mirror_rp.index, self.relevant_incs[-1].lstat())
 		current_fp = self.get_first_fp()
 		for inc_diff in self.relevant_incs[1:]:
 			log.Log("Applying patch %s" % (inc_diff.get_indexpath(),), 7)
@@ -522,7 +533,7 @@ class PatchITRB(rorpiter.ITRBranch):
 		assert diff_rorp.get_attached_filetype() == 'snapshot'
 		self.dir_replacement = TempFile.new(base_rp)
 		rpath.copy_with_attribs(diff_rorp, self.dir_replacement)
-		if base_rp.isdir(): base_rp.chmod(0700)
+		if base_rp.isdir() and Globals.change_permissions: base_rp.chmod(0700)
 
 	def prepare_dir(self, diff_rorp, base_rp):
 		"""Prepare base_rp to turn into a directory"""
@@ -530,7 +541,7 @@ class PatchITRB(rorpiter.ITRBranch):
 		if not base_rp.isdir():
 			if base_rp.lstat(): base_rp.delete()
 			base_rp.mkdir()
-		base_rp.chmod(0700)
+		if Globals.change_permissions: base_rp.chmod(0700)
 
 	def end_process(self):
 		"""Finish processing directory"""
